==> haskell-shakespeare-2.0.12.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.12.1
id: shakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
key: shakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
abi: 6b9739a419286178c1f86475595cbbc3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.12.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.12.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/shakespeare-2.0.12.1
hs-libraries: HSshakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN ghc-prim-0.5.0.0
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.12-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.12
id: shakespeare-2.0.12-4ppL9xZ9sKD6RsPGnrhiq
key: shakespeare-2.0.12-4ppL9xZ9sKD6RsPGnrhiq
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
abi: 418a33553c679cda2f6d8e878ac332fb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.12
data-dir: /usr/share/i386-linux-ghc-8.0.1/shakespeare-2.0.12
hs-libraries: HSshakespeare-2.0.12-4ppL9xZ9sKD6RsPGnrhiq
depends:
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN ghc-prim-0.5.0.0
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
